netapp_ontap.models.iscsi_session_initiator API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.iscsi_session_initiator`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class IscsiSessionInitiatorSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the IscsiSessionInitiator object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `alias GET`

    The initiator alias.

    Example: initiator_alias1

  `name GET`

    The world wide unique name of the initiator.

    Example: iqn.1992-01.example.com:string